SystemOrganization addCategory: #Matcher!
SystemOrganization addCategory: #'Matcher-Test'!

TestCase subclass: #MatcherTest
	instanceVariableNames: 'techTicketApp someTicket someTicketId testTech workerMatchApp someProject someProjectId pepe'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher-Test'!

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:37'!
setUp
	self setUpTicketTests.
	self setUpProjectTests.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:45'!
setUpProjectTests
	| newProject worker |
	someProject := Project newWithDescription: 'Some Project' priority: 1 dueBy: (Date today) createdBy: (MatcherUser fullName: 'Pepe Smith').
	someProject addRequirement: (workerMatchApp getMatchItemByName: 'Coding')."skil"
	someProject addRequirement: (workerMatchApp getMatchItemByName: 'HTML')."skill"
	someProject addRequirement: (workerMatchApp getMatchItemByName: 'ECommerce'). "location"
	someProjectId := workerMatchApp addMatchActivity: someProject.
	
	"Worker Creation"
	pepe := Worker withFirstName: 'Pepe' lastName: 'Skillz' address: '0 Worker Way' city: 'Worker Town' state: 'WA' zip: '22333' phone: '5555551414'.
	pepe assignMatchItem: (workerMatchApp getMatchItemByName: 'Coding').
	pepe assignMatchItem: (workerMatchApp getMatchItemByName: 'HTML').
	workerMatchApp addMatchResource: pepe.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:21'!
setUpTicketTests
	| tech newProject |
	
	MatcherSkill setWeight: 0.7.
	MatcherLocation setWeight: 0.3.
	
	techTicketApp := TechTicketApp default.
	techTicketApp initialize.
	techTicketApp privateClearItems.
	workerMatchApp := WorkerMatchApp default.
	workerMatchApp initialize.
	workerMatchApp privateClearItems.

	tech := (Tech withFirstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Philadelphia').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Washington DC').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Computer Repair').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Testing').
	techTicketApp addMatchResource: tech.
	
	tech := (Tech withFirstName: 'Empty' lastName: 'Skills' address: '0 Tech Way' city: 'Tech Town' state: 'WA' zip: '22333' phone: '5555551414').
	techTicketApp addMatchResource: tech.
	
	tech := (Tech withFirstName: 'Bill' lastName: 'Lumberg' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Orlando').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Computer Repair').
	tech assignMatchItem: (techTicketApp getMatchItemByName: 'Java').
	techTicketApp addMatchResource: tech.
	
	someTicket := Ticket newWithDescription: 'Test Ticket' priority: 1 dueBy: (Date today) createdBy: (MatcherUser fullName: 'Pepe Smith').
	someTicket addRequirement: (techTicketApp getMatchItemByName: 'Testing').
	someTicket addRequirement: (techTicketApp getMatchItemByName: 'Computer Repair').
	someTicket addRequirement: (techTicketApp getMatchItemByName: 'New York City').

	someTicketId := techTicketApp addMatchActivity: (someTicket).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:41'!
testMatchBestWorkerByScore
"Second worker has 0 score in the skills match"
| worker addedTicketNum resultingWorkers |
"see setUp for Pepe and someProject"
worker := Worker withFirstName: 'Juanito' lastName: 'Augenblick' address: '123 Main Street' city: 'Shiny Town' state: 'TX' zip: '12333' phone: '5555555454'.
worker assignMatchItem: (workerMatchApp getMatchItemByName: 'HTML').
workerMatchApp addMatchResource: worker.

resultingWorkers := workerMatchApp matchWorkerForProject: someProject.

Transcript show: (someProject bestMatchDictionary).  Transcript cr.

self assert: resultingWorkers size = 2.

self assert: (someProject matchWithTopScore) getResource fullName = 'Pepe Skillz'.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:47'!
testMatchBestWorkerForProjectOutOfPoolOfWorkers
"Second worker has 0 score in the skills match"
| resultingWorkers |

workerMatchApp addMatchResource:  (Worker withFirstName: 'Juanito' lastName: 'Augenblick' address: '123 Main Street' city: 'Shiny Town' state: 'TX' zip: '12333' phone: '5555555454').

resultingWorkers := workerMatchApp matchWorkerForProject: someProject.

Transcript show: (someProject bestMatchDictionary).  Transcript cr.

self assert: resultingWorkers size = 1.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:52'!
testMatchProjectFindNoWorker
| resultingWorkers |

"Worker Creation"
workerMatchApp addMatchResource:  (Worker withFirstName: 'PepeNo' lastName: 'Skillz' address: '0 Worker Way' city: 'Worker Town' state: 'WA' zip: '22333' phone: '5555551414' ).

workerMatchApp removeMatchResource: pepe.

resultingWorkers := workerMatchApp matchWorkerForProject:  someProject.

Transcript show: (someProject bestMatchDictionary).  Transcript cr.

self assert: resultingWorkers size = 0.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:54'!
testMatchProjectWithWorker
| resultingWorkers |

resultingWorkers := workerMatchApp matchWorkerForProject: someProject.

self assert: resultingWorkers size = 1.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:34'!
testMatchTicketWithTech
| resultingTechs |

resultingTechs := techTicketApp findTechMatchForTicket: someTicket.

Transcript show: (someTicket bestMatchDictionary).  Transcript cr.

self assert: resultingTechs size = 2.

self assert: (someTicket matchWithTopScore) getResource fullName = 'Test Techer'.

! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 17:20'!
testMatchingScoreAvailableAt

| skillColl locColl traitsColl worker daysAvailable |
skillColl := Skills new.
locColl := Locations new.
traitsColl :=  Traits new.
daysAvailable := DaysAvailable new.
daysAvailable addAll: #(monday wednesday friday).

worker := Worker withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

self assert: 100 = (worker isAvailableAt: #(wednesday friday)) getScore.
self assert: 50 = (worker isAvailableAt: #(thursday friday)) getScore.
self assert: 33 = (worker isAvailableAt: #(sunday thursday friday)) getScore.
self assert: 0 = (worker isAvailableAt: #(saturday)) getScore.

self assert: (worker isAvailableAt: #(wednesday friday)) isFullMatch.
self deny: (worker isAvailableAt: #(thursday friday)) isFullMatch.
self deny: (worker isAvailableAt: #(thursday friday)) isFullMatch.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 17:10'!
testMatchingScoreSkills

| skillColl locColl traitsColl worker daysAvailColl requiredSkills |
skillColl := Skills new.
skillColl add: ((workerMatchApp getSkillByName: 'html') level: 0).
skillColl add: ((workerMatchApp getSkillByName: 'css') level: 0).
skillColl add: ((workerMatchApp getSkillByName: 'php') level: 0).
locColl := Locations new.
traitsColl := Traits new.
daysAvailColl := DaysAvailable  new.

worker := Worker withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailColl.

self assert: 100 = (worker getSkillsScore: skillColl) getScore. 

"Required skills"
requiredSkills := OrderedCollection new.
requiredSkills add: ((workerMatchApp getSkillByName: 'html') level: 0).
requiredSkills add: ((workerMatchApp getSkillByName: 'css') level: 0).
requiredSkills add: ((workerMatchApp getSkillByName: 'javscript') level: 0).

Transcript show:(worker getSkillsScore: requiredSkills) getScore.

self assert: 67 = (worker getSkillsScore: requiredSkills) getScore. 
! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:21'!
testPersonCreation

| skillColl locColl person|
skillColl := OrderedCollection new.
locColl := OrderedCollection new.

person := MatcherResource withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212'.

self assert: 'Test Techer'  = person fullName.
self assert: '1 Tech Way, Tech City, PA 19191'  = person fullAddress.! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 22:14'!
testTechCreation
| skillColl locColl certColl tech |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.
certColl := #(ccna microsoft) asOrderedCollection.

skillColl add: ((techTicketApp getSkillByName: 'Testing') level: 2).
skillColl add: ((techTicketApp getSkillByName: 'Computer Repair') level: 2).
locColl add: (techTicketApp getLocationByName: 'Orlando').

tech := (Tech withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212'  certificationsCollection: certColl).

techTicketApp addTech: tech.

self assert: true = (tech hasCertification: #ccna).

self assert: (tech hasSkill: ((techTicketApp getSkillByName: 'Computer Repair') level: 1)).
self deny: (tech hasSkill: ((techTicketApp getSkillByName: 'Computer Repair') level: 9)).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'MattF 4/16/2013 23:16'!
testTicketCreation
| skillColl locColl certColl tech addedTicketNum newTicket |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.

skillColl add: (MatcherSkill withName: 'Testing' level: 2 description: 'This is a level 2 of 10 skill').
skillColl add: (techTicketApp getSkillByName: 'Computer Repair').
locColl add: (MatcherLocation newWithName: 'Test City' address: '1 Test Street' city: 'Test City' state: 'FL' additionalInfo: 'A place to test').

newTicket := Ticket newWithDescription: 'Test Ticket' priority: 1 dueBy: (DateAndTime now) locations: locColl reqSkillsCollection: skillColl createdBy: (MatcherUser fullName: 'Pepe Smith').

addedTicketNum := techTicketApp addTicket: (newTicket).

Transcript show: techTicketApp reportTicketVolumeByHour.

"self assert: (techTicketApp nextTicketId) = ((techTicketApp ticketCount)+1).
self assert: addedTicketNum = ((techTicketApp nextTicketId)-1).
self assert: (((techTicketApp getTicketById: addedTicketNum) status) getName) = 'Open'."! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 15:58'!
testWorkerCreation

| skillColl locColl traitsColl worker daysAvailable |

traitsColl := Traits new.
traitsColl add:#fun.

skillColl := Skills new.
skillColl add: (workerMatchApp getSkillByName: 'Java').

locColl := Locations new.
locColl add: (workerMatchApp getLocationByName: 'New York City').

daysAvailable := #(monday wednesday friday) asOrderedCollection.

"changing something.. trying to commit..."

worker := Worker withSkillsCollection: skillColl locationCollection: locColl firstName: 'Test' lastName: 'Techer' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

traitsColl add:#fun.
skillColl add:  (workerMatchApp  getSkillByName: 'Java').
"these need to use the entrepreur app (obviously) but should not be storing symbols in a skillsArray"
"which I assumed would be storing ONLY MatcherSkills... so I changed them to use techApp's defaults for the time being"
locColl add: (workerMatchApp getLocationByName: 'New York City').
"Same as above... should be MatcherLocations, I think... it was just a symbol here"

self assert: 'Test Techer'  = worker fullName.
self assert: '1 Tech Way, Tech City, PA 19191'  = worker fullAddress.
self assert: true = (worker hasTrait: #fun).
self assert: true = (worker hasSkill: (workerMatchApp getSkillByName: 'Java')). "changed from symbol"
self assert: true = (worker hasLocation: (workerMatchApp getLocationByName: 'New York City')).! !

!MatcherTest methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 13:45'!
testWorkerMatchApp
|skillColl locColl traitsColl workerOne workerTwo daysAvailable countBeforeAdding |

skillColl := OrderedCollection new.
locColl := OrderedCollection new.
traitsColl := OrderedCollection new.
daysAvailable := #(monday wednesday friday) asOrderedCollection.

workerOne := Worker withSkillsCollection: skillColl locationCollection: locColl firstName: 'John' lastName: 'Rodriguez' address: '123 Mainstreet' city: 'Sunrise' state: 'FL' zip: '33326' phone: '3063933939' traits: traitsColl daysAvailable: daysAvailable.

workerTwo := Worker withSkillsCollection: skillColl locationCollection: locColl firstName: 'Pepe' lastName: 'Smith' address: '1 Tech Way' city: 'Tech City' state: 'PA' zip: '19191' phone: '5555551212' traits: traitsColl daysAvailable: daysAvailable.

countBeforeAdding:= workerMatchApp workerCount.

workerMatchApp addWorker: workerOne.
workerMatchApp addWorker: workerTwo.
self assert:  (workerMatchApp workerCount) = (countBeforeAdding+2).! !

OrderedCollection subclass: #MatcherItems
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherItems subclass: #Certifications
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Certifications methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:16'!
label
	^'Certifications'! !

MatcherItems subclass: #DaysAvailable
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!DaysAvailable methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:18'!
label
	^'Days Available'! !

MatcherItems subclass: #Locations
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Locations methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:16'!
label
	^'Locations'! !

!MatcherItems class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:14'!
withCollection: aCollection
	^self new withCollection: aCollection! !

!MatcherItems methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 18:08'!
getMatchScore: resourceCriterias forResource: aResource
|totalScore setSize setMatch|

(self hasEqualElements:  resourceCriterias) 
	ifTrue: [^MatcherScore newWithScore: 100 andResource: aResource].

setSize := resourceCriterias size.
setMatch := 0.

(setSize = 0) 
	ifTrue: [^MatcherScore newWithScore: 0 andResource: aResource].

resourceCriterias do: [ :criteria | 
	(self includes: criteria) 
		ifFalse: [
			
			setMatch := setMatch + 1.
			
			]. 
		].
	
	
totalScore := ((setSize - setMatch)*100)/setSize.
	
^MatcherScore newWithScore: ((totalScore * 1.00) rounded) andResource: aResource! !

!MatcherItems methodsFor: 'adding' stamp: 'HectorGonzalez 4/19/2013 13:42'!
withCollection: aCollection
	self addAllLast: aCollection! !

MatcherItems subclass: #Skills
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Skills methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:15'!
label
	^'Skills'! !

MatcherItems subclass: #Traits
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Traits methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:17'!
label
	^'Traits'! !

Object subclass: #MatcherActivity
	instanceVariableNames: 'id requirements description status creator bestMatchDictionary priority dueByTime assignedPersonsDictionary creationDate lastFetch'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherActivity class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:39'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate createdBy: user

^ self new newWithDescription: desc priority: priorityNum dueBy: dueByDate createdBy: user

! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 17:59'!
addBestMatchRun: aMatchDictionary
	"The idea here is to keep track of matches for any given item, i.e. a ticket has a matcher algorithm run on it (see it in TechTicketApp) which then"
	"creates a dictionary of best matches with the mapping Tech->MatcherScore.  This dictionary is then a member of the matchDictionary variable"
	"in this class, which has keys which are the dates they were added/generated so we can see progress over time."
	lastFetch := DateAndTime now.
	bestMatchDictionary at: (lastFetch) put: aMatchDictionary ! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 22:41'!
addRequirement: aMatcherItem
	requirements add: aMatcherItem.! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 22:47'!
addRequirementList: aMatcherItemOrdList
	aMatcherItemOrdList do: [:ele | requirements add: ele].! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 22:39'!
bestMatchDictionary
	^ bestMatchDictionary! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'MattF 4/16/2013 22:02'!
creationDate
	^ creationDate! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 22:41'!
id
	^ id.! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/16/2013 22:16'!
isClosed
	^ (status = MatcherStatus Closed)! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/16/2013 22:16'!
isOpen
	^ (status = MatcherStatus Open)! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 17:59'!
matchWithTopScore
|topResource|

(bestMatchDictionary at:lastFetch) do: [:resource|	
		(topResource = nil)
			ifTrue:[
				topResource := resource.
			].		
		(resource getScore) >  (topResource getScore)
			ifTrue:[
				topResource := resource.
			].
	].

^ topResource.! !

!MatcherActivity methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:59'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate  createdBy: user


description := desc.
priority := priorityNum.
dueByTime := dueByDate.
status := MatcherStatus Open. 
creator := user.
assignedPersonsDictionary := Dictionary new.
requirements := MatcherItems new.
bestMatchDictionary := Dictionary new.
creationDate := (DateAndTime now).
! !

MatcherActivity subclass: #Project
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Project methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/16/2013 22:12'!
assignEntrepreneur: anEntrepreneur
	assignedPersonsDictionary at: anEntrepreneur add: Date today.
	anEntrepreneur privateAssignProject: self.! !

!Project methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:07'!
matchScore: aWorker
|workerSkills score_obj|
workerSkills := aWorker matchItemList.
score_obj := requirements getMatchScore: workerSkills  forResource: aWorker.

^ score_obj.! !

!Project methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:55'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate  createdBy: user

id := WorkerMatchApp default nextActivityId.
super newWithDescription: desc priority: priorityNum dueBy: dueByDate createdBy: user.! !

MatcherActivity subclass: #Ticket
	instanceVariableNames: 'completionTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Ticket methodsFor: 'as yet unclassified' stamp: 'MattF 4/16/2013 22:06'!
assignTech: aTech
	assignedPersonsDictionary at: aTech add: (DateAndTime now).
	aTech privateAssignTicket: self.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 21:00'!
closeTicket
	status := MatcherStatus Closed.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:32'!
matchScore: aTech
"accepts a ticket object and a tech object to provide a score or true/false for how well they match up"
"not sure if this should be in its own class for a good pattern use somewhere"
| tempScore tempCount countDict |
countDict := Dictionary new.
"I am going to use this dictionary to count the number of each type of item so I can divide to weight them properly."
"If anyone reading this has an idea of math I am missing to do this as we iterate I am all ears."

tempScore := 0.
tempCount := (requirements) size.
(requirements size) > 0 
	ifTrue: [requirements do: 
				[:ele | (aTech hasMatchItem: ele) ifTrue: [tempScore := (tempScore asFloat) + (ele class weight)].  
					countDict at: ((ele class) asString asSymbol) put: ((countDict at: ((ele class) asString asSymbol) ifAbsent: [0]) + 1)]. 
				tempScore :=  tempScore / tempCount * 100.] 
	ifFalse: [tempScore := 100]. 
	Transcript cr.
	Transcript show: 'COUNT DICT:'.
Transcript show: countDict.
"The weighting is now set in the class variable weight by MatcherItem type, which could be set up by the user or just on app startup"
"This allows a dynamic list of requirements objects without us having to know what type they are but still get a weighted score"

^ MatcherScore newWithScore: tempScore andResource: aTech.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:55'!
newWithDescription: desc priority: priorityNum dueBy: dueByDate  createdBy: user

id := TechTicketApp default nextActivityId.
super newWithDescription: desc priority: priorityNum dueBy: dueByDate createdBy: user.! !

!Ticket methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 21:16'!
removeTech: aTech
	assignedPersonsDictionary removeKey: aTech.
	aTech privateRemoveTicket: self.! !

Object subclass: #MatcherHistorical
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherHistorical methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 21:58'!
README
"this is a purely a placeholder so I don't forget the idea (if we have time) of adding in historical changes to matcher items like tickets or projects"! !

Object subclass: #MatcherHours
	instanceVariableNames: 'beginAvailable endAvailable onCallBegin onCallEnd'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherHours methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 12:35'!
withBeginTime: aBeginTime endTime: anEndTime

beginAvailable := aBeginTime .
endAvailable := anEndTime .
onCallBegin := Time midnight.
onCallEnd := Time midnight.! !

!MatcherHours methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 12:35'!
withBeginTime: aBeginTime endTime: anEndTime onCallBeginTime: anOnCallBeginTime onCallEndTime: anOnCallEndTime

beginAvailable := aBeginTime .
endAvailable := anEndTime .
onCallBegin := anOnCallBeginTime.
onCallEnd := anOnCallEndTime.! !

Object subclass: #MatcherItem
	instanceVariableNames: 'name description level createdDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherItem class
	instanceVariableNames: 'weight'!

MatcherItem class
	instanceVariableNames: 'weight'!

MatcherItem subclass: #MatcherCertification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherItem class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 16:41'!
setWeight: aNumber
	(aNumber > 1 | aNumber < 0) ifTrue: [self error: 'Weights should be between zero and one.'] ifFalse: [weight := aNumber].! !

!MatcherItem class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 16:47'!
weight
	^ weight.! !

!MatcherItem class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 16:46'!
withName: aName andDescription:aDescription
	^ self new withName: aName andDescription: aDescription.! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:18'!
= aMatcherItem
	(self class) = (aMatcherItem class) ifFalse: [^ false].
	(self getName = aMatcherItem getName) ifTrue: [^ true].
	^ false.! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:04'!
getDescription
^description! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:04'!
getName
^name! !

!MatcherItem methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 17:42'!
withName: aName andDescription:aDescription
name:= aName.
description:=aDescription.
createdDate := (DateAndTime now).! !

MatcherItem subclass: #MatcherLocation
	instanceVariableNames: 'address city state additionalInfo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherLocation class methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 01:02'!
empty

^ (MatcherLocation new) newWithName: 'Unknown' address: '' city: '' state: '' additionalInfo: 'Location has not been set'! !

!MatcherLocation class methodsFor: 'as yet unclassified' stamp: 'MattF 3/31/2013 13:04'!
newWithName: strName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo

^ self new newWithName: strName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo.! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:18'!
= aMatcherLocation
	(self class) = (aMatcherLocation class) ifFalse: [^ false].
	(self address = aMatcherLocation address & self city = aMatcherLocation city & self state = aMatcherLocation state) ifTrue: [^ true].
	^ false.! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'Mattf 4/10/2013 21:52'!
address
	^ address! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'Mattf 4/10/2013 21:53'!
city
	^ city! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:18'!
newWithName: aName address: strAddress city: strCity state: strState additionalInfo: strAdditionalInfo
address := strAddress.
city := strCity.
state := strState.
additionalInfo := strAdditionalInfo.

super withName:aName andDescription:''.! !

!MatcherLocation methodsFor: 'as yet unclassified' stamp: 'Mattf 4/10/2013 21:53'!
state
	^ state! !

MatcherItem subclass: #MatcherSkill
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherSkill class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 22:32'!
withName: strName level: numLevel description: strDesc

^ self new withName: strName level: numLevel description: strDesc.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 17:18'!
= aMatcherSkill
	(self class) = (aMatcherSkill class) ifFalse: [^ false].
	(aMatcherSkill getName = self getName) & (aMatcherSkill @ self) ifTrue: [^ true].
	^ false.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:03'!
@ aMatcherSkill
	"Equals is defined in MatcherItem since that can just be name... but this shorthand should help us"
	"tell if a given skill is at or higher than the skill passed to it, hence use of @"
	(self level >= aMatcherSkill level) ifTrue: [^ true].
	^ false.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'Mattf 4/10/2013 22:34'!
level
	^ level! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'Mattf 4/10/2013 23:22'!
level: aNumber
	level := aNumber.! !

!MatcherSkill methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:17'!
withName: aName level: numLevel description: aDescription
level := numLevel .
super withName:aName andDescription: aDescription.! !

MatcherItem subclass: #MatcherStatus
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherStatus class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 20:58'!
Closed
	^ self new newWithName: 'Closed'.! !

!MatcherStatus class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 20:58'!
Open
	^ self new newWithName: 'Open'.! !

!MatcherStatus class methodsFor: 'as yet unclassified' stamp: 'Mattf 4/7/2013 20:59'!
newWithName: aName
	^ self new newWithName: aName.! !

!MatcherStatus methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:19'!
newWithName: aName
	"I called this strName because name was overriding some base method in Object, which didn't seem right to do"
super withName:aName andDescription: ''.! !

Object subclass: #MatcherItemResourceStrategy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherItemResourceStrategy subclass: #LocationMatchOnly
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherItemResourceStrategy methodsFor: 'as yet unclassified' stamp: 'Mattf 4/11/2013 19:56'!
match: aTech withTicket: aTicket withSkills: skills withLocations: locations withCertifications: certifications
 ^ self subclassResponsibility ! !

MatcherItemResourceStrategy subclass: #SkillLocationMatch
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

Object subclass: #MatcherMainApp
	instanceVariableNames: 'masterMatchItemCollection activityCollection resourceCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherMainApp class
	instanceVariableNames: 'soleInstance'!

MatcherMainApp class
	instanceVariableNames: 'soleInstance'!

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:27'!
activityCount
	^ activityCollection size.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:30'!
addMatchActivity: aMatcherActivity
	activityCollection add: aMatcherActivity.
	^ aMatcherActivity id! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:50'!
addMatchItem: aMatcherItem
	masterMatchItemCollection add: aMatcherItem.
! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:21'!
addMatchResource: aMatcherResource
	resourceCollection add: aMatcherResource.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:24'!
getMatchActivityById: anIdNumber
	"Returns a ticket based on it's ID number"
	| aTicket |
	^ activityCollection do: [:ele | ((ele id) = anIdNumber) ifTrue: [ ^ ele ] ].! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 01:28'!
getMatchItemByName: aName
	masterMatchItemCollection do: [:ele | (ele getName = aName) 
		ifTrue: [^ ele copy]
		].
	self error: 'Item not found (', aName, '), add it to the system first'..! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:08'!
initialize
	masterMatchItemCollection := MatcherItems new.
	activityCollection := OrderedCollection new.
	resourceCollection := MatcherItems new.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:43'!
nextActivityId
"Provides the next activity id from the system, so we don't ever re-use an ID"
	| newActivityNum |
	newActivityNum := 1.
	(activityCollection size = 0) ifTrue:[^newActivityNum].
	activityCollection do: [:element | 
		((element = nil) or: (element id) = nil) ifFalse: [ 
			
							((element id) >= newActivityNum)
							 ifTrue: [newActivityNum := (element id) +1]
			
								].
	].
	^ newActivityNum.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 01:24'!
privateClearItems
	self initialize.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:49'!
removeMatchActivity: aMatcherActivity
	activityCollection remove: aMatcherActivity.
	^ aMatcherActivity id! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:51'!
removeMatchItem: aMatcherItem
	masterMatchItemCollection remove: aMatcherItem.
! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 15:49'!
removeMatchResource: aMatcherResource
	resourceCollection remove: aMatcherResource.! !

!MatcherMainApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:27'!
resourceCount
	^ resourceCollection size.! !

MatcherMainApp subclass: #TechTicketApp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!TechTicketApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:31'!
default
	(soleInstance isNil) ifTrue: [soleInstance := super new initialize].
	^ soleInstance.! !

!TechTicketApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:34'!
new
	self error: 'This is a singleton, use default'! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:22'!
findTechMatchForTicket: aTicket
	"Provides a dictionary of scores, with techs as keys for a given issue"
	| matchesDict checkScore |
	matchesDict  := Dictionary new.
	resourceCollection do: [:techEle | 
		checkScore := (aTicket matchScore: techEle).  
		(checkScore getScore) = 0 ifFalse: [matchesDict at: techEle put: checkScore ]].
	
	aTicket addBestMatchRun: matchesDict.
	
	^ matchesDict.
	! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 01:03'!
initialize 
"Start up the main app object with some default values for logical items and initialize the others to a base collection"

super initialize .
 
"there should be some default locations I would think...user can take them out if not needed?"
masterMatchItemCollection add: (MatcherLocation newWithName: 'New York City' address: '1 Main St.' city: 'New York' state: 'NY' additionalInfo: 'Main NY Office').
masterMatchItemCollection add: (MatcherLocation newWithName: 'Washington DC' address: '1600 Pennsylvania Ave.' city: 'Washington' state: 'DC' additionalInfo: 'Main DC Office').
masterMatchItemCollection add: (MatcherLocation newWithName: 'San Francisco' address: '100 Lombard St.' city: 'San Francisco' state: 'CA' additionalInfo: 'Main SF Office').
masterMatchItemCollection add: (MatcherLocation newWithName: 'Orlando' address: '876 Disney Pl.' city: 'Orlando' state: 'FL' additionalInfo: 'Main FL Office').
masterMatchItemCollection add: (MatcherLocation newWithName: 'Philadelphia' address: '2 Bell Blvd.' city: 'Philadelphia' state: 'PA' additionalInfo: 'Main PHL Office').

"adding in some base skills... no point in adding a level, that should be user set for either the ticket to assign it to or the tech to assign it to... this will just allow us a base list to show"
masterMatchItemCollection add: (MatcherSkill withName: 'Computer Repair' level: 0 description: 'Ability to fix computers').
masterMatchItemCollection add: (MatcherSkill withName: 'Electrical Repair' level: 0 description: 'Electrical Certification').
masterMatchItemCollection add: (MatcherSkill withName: 'Testing' level: 0 description: 'Apitude as a tester').
masterMatchItemCollection add: (MatcherSkill withName: 'Java' level: 0 description: 'Apitude in Java').
masterMatchItemCollection add: (MatcherSkill withName: 'Teaching' level: 0 description: 'Ability to teach').

! !

!TechTicketApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:04'!
reportTicketVolumeByHour
	| resultsColl |
	resultsColl := OrderedCollection newFrom: (0 to: 24 by: 0.5).
	resultsColl := Dictionary newFromPairs: resultsColl.
	resultsColl keysDo: [:ele | resultsColl at: ele put: 0].
	
	activityCollection do: [:ele | resultsColl at: ((ele creationDate) hour24) put: ((resultsColl at: ((ele creationDate) hour24))+1)].
	^ resultsColl 
	
	! !

MatcherMainApp subclass: #WorkerMatchApp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!WorkerMatchApp class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:30'!
default
	(soleInstance isNil) ifTrue: [soleInstance := super new initialize].
	^ soleInstance.! !

!WorkerMatchApp class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 11:34'!
new
	self error: 'This is a singleton, use default'! !

!WorkerMatchApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 01:29'!
initialize 

super initialize .

masterMatchItemCollection add: (MatcherSkill withName: 'HTML' level: 0 description: 'Ability to write HTML').
masterMatchItemCollection add: (MatcherSkill withName: 'CSS' level: 0 description: 'Ability to write CSS').
masterMatchItemCollection add: (MatcherSkill withName: 'PHP' level: 0 description: 'Ability to write PHP').
masterMatchItemCollection add: (MatcherSkill withName: 'Coding' level: 0 description: 'Ability to Code').

masterMatchItemCollection add: (MatcherLocation newWithName: 'New York City' address: '1 Main St.' city: 'New York' state: 'NY' additionalInfo: 'Main NY Office').
masterMatchItemCollection add: (MatcherLocation newWithName: 'ECommerce' address: 'N/A' city: 'N/A' state: '' additionalInfo: 'Online Store').! !

!WorkerMatchApp methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:04'!
matchWorkerForProject: aProject
	"Provides a dictionary of scores, with techs as keys for a given issue"
	| matchesDict workerScore value |
	matchesDict  := Dictionary new.
	resourceCollection do: [:worker| 
		workerScore := (aProject matchScore: worker). 
		(workerScore getScore) > 0 
			ifTrue: [matchesDict at: worker put: workerScore ]].
	
	aProject addBestMatchRun: matchesDict.
	
	^ matchesDict.! !

Object subclass: #MatcherResource
	instanceVariableNames: 'id matchItemList matchActivityList fname lname address city state zip phone description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherResource class methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:34'!
withFirstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone

^ self new withFirstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:11'!
assignMatchItem: aMatcherItem
	matchItemList add: aMatcherItem.! !

!MatcherResource methodsFor: 'accessing' stamp: 'HectorGonzalez 3/31/2013 20:57'!
fullAddress
	^ (address, ', ', city, ', ', state, ' ', zip)! !

!MatcherResource methodsFor: 'accessing' stamp: 'HectorGonzalez 3/31/2013 20:48'!
fullName
  ^(fname, ' ', lname)! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'MattF 4/19/2013 23:00'!
hasMatchItem: aMatchItem
	^(matchItemList includes: aMatchItem).! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 14:23'!
id
	^ id.! !

!MatcherResource methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 00:07'!
matchItemList
	^ matchItemList ! !

!MatcherResource methodsFor: 'testing' stamp: 'Mattf 4/13/2013 22:44'!
printOn: aStream
	self fullName printOn: aStream.! !

!MatcherResource methodsFor: 'testing' stamp: 'MattF 4/20/2013 01:07'!
privateAssignActivity: aMatcherActivity
	matchActivityList at: aMatcherActivity put: (DateAndTime now)! !

!MatcherResource methodsFor: 'testing' stamp: 'MattF 4/20/2013 01:08'!
privateRemoveActivity: aMatcherActivity
	matchActivityList removeKey: aMatcherActivity! !

!MatcherResource methodsFor: 'initialize-release' stamp: 'MattF 4/19/2013 23:04'!
withFirstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone
	
fname := strFName.
lname := strLName.
address := strAddress.
city := strCity.
state := strState.
zip := strZip.
phone := strPhone.
matchItemList := OrderedCollection new.! !

MatcherResource subclass: #Tech
	instanceVariableNames: 'currentLocation weeklyScheduleDict'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Tech methodsFor: 'as yet unclassified' stamp: 'MattF 4/20/2013 01:09'!
withFirstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone

super 		withFirstName: strFName 
			lastName: strLName 
			address: strAddress 
			city: strCity 
			state: strState 
			zip: strZip 
			phone: strPhone.

currentLocation := nil.
weeklyScheduleDict := Dictionary new.
weeklyScheduleDict at: #sunday put: OrderedCollection new. "new object for times in these days??"
weeklyScheduleDict at: #monday put: OrderedCollection new.
weeklyScheduleDict at: #tuesday put: OrderedCollection new.
weeklyScheduleDict at: #wednesday put: OrderedCollection new.
weeklyScheduleDict at: #thursday put: OrderedCollection new.
weeklyScheduleDict at: #friday put: OrderedCollection new.
weeklyScheduleDict at: #saturday put: OrderedCollection new.! !

MatcherResource subclass: #Worker
	instanceVariableNames: 'traits daysAvailable'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!Worker class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/1/2013 00:09'!
withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone traits: traitsArr daysAvailable: aSetOfDaysAvailable

^ self new withSkillsCollection: skillsArr locationCollection: locationArr firstName: strFName lastName: strLName address: strAddress city: strCity state: strState zip: strZip phone: strPhone traits: traitsArr daysAvailable: aSetOfDaysAvailable.

! !

!Worker methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 18:07'!
getSkillsScore: theseSkills
	^(skills getMatchScore:  theseSkills forResource: self).! !

!Worker methodsFor: 'testing' stamp: 'HectorGonzalez 4/19/2013 18:09'!
isAvailableAt: theseDays
	^(daysAvailable getMatchScore:  theseDays forResource: self).! !

Object subclass: #MatcherScore
	instanceVariableNames: 'score fullMatch resource'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

MatcherScore class
	instanceVariableNames: 'scaleDictionary'!

MatcherScore class
	instanceVariableNames: 'scaleDictionary'!

!MatcherScore class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 18:02'!
newWithScore: aNumber andResource:aResource
	^ self new newWithScore: aNumber andResource: aResource.! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 18:01'!
getResource
	^resource! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 10:43'!
getScore
	^score! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:33'!
isFullMatch
	^(score = 100).! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/8/2013 13:32'!
newWithScore: aNumber
	score := aNumber.! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/19/2013 18:01'!
newWithScore: aNumber andResource: aResource
	score := aNumber.
	resource := aResource.! !

!MatcherScore methodsFor: 'as yet unclassified' stamp: 'Mattf 4/13/2013 22:43'!
printOn: aStream
	score printOn: aStream.! !

Object subclass: #MatcherUser
	instanceVariableNames: 'fullName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Matcher'!

!MatcherUser class methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/7/2013 17:48'!
fullName: aFullName
	^self new fullName: aFullName! !

!MatcherUser methodsFor: 'as yet unclassified' stamp: 'HectorGonzalez 4/7/2013 17:49'!
fullName: aFullName
fullName:=aFullName! !
